@@ -1,14 +1,17 @@
+# Try to run the qt magic first, in case we're in ipython
+# try:    get_ipython().run_line_magic('gui', 'qt')
+# except: print('terminal')
+
 import os           as _os
 import sys          as _sys
-import matplotlib   as _mpl
+import matplotlib   as _mpl; _mpl.use('qtagg')
 import pylab
 
+# WEIRD HACK THAT MAKES QT WORK IN SPYDER, WINDOWS CMD; no solution for pycharm :\
+pylab.ioff()
+pylab.ion()
+
 
-# Try to run the qt magic first
-try:
-    if not pylab.get_backend()[0:2] == 'Qt':
-        get_ipython().run_line_magic('matplotlib', 'qt')
-except: pass
 
 import traceback    as _traceback
 _sys.excepthook = _traceback.print_exception
@@ -44,20 +47,22 @@ def _warn(*args):
 
 try:
     import pyqtgraph as _pyqtgraph
-    _pyqtgraph_ok = float('.'.join(_pyqtgraph.__version__.split('.')[0:2])) > 0.1
+    _pyqtgraph_version = float('.'.join(_pyqtgraph.__version__.split('.')[0:2]))
+    _pyqtgraph_ok = _pyqtgraph_version >= 0.11 # Used elsewhere
 
     if not _pyqtgraph_ok: _warn('Spinmob requires pyqtgraph version 0.11 or higher. Previous versions are no longer supported.')
 
     _qtc = _pyqtgraph.Qt.QtCore
     _qt  = _pyqtgraph.Qt
-    _qtw = _pyqtgraph.Qt.QtGui
+    if _pyqtgraph_version < 0.13: _qtw = _pyqtgraph.Qt.QtGui
+    else:                         _qtw = _pyqtgraph.Qt.QtWidgets
 
     # make sure we have a valid qt application for dialogs etc...
-    _qtapp = _qtc.QCoreApplication.instance()
+    _qtapp = _qt.QtWidgets.QApplication.instance()
     if not _qtapp: _qtapp = _qtw.QApplication([])
 
     # Set the dpi scaling
-    _qtapp.setAttribute(_qtc.Qt.AA_EnableHighDpiScaling, True)
+    #_qtapp.setAttribute(_qtc.Qt.AA_EnableHighDpiScaling, True)
 
     # Standard Fusion light theme
     _qtapp.setStyle('Fusion')
@@ -66,7 +71,8 @@ try:
     if settings['dark_theme_qt']: from . import _theme_fusion_dark
 
 
-except:
+except Exception as e:
+    print(e)
     _warn("pyqtgraph version 0.11 or higher is required (use a conda or pip install).")
 
     _qtc = None
